<?php

namespace Teste\Teste\Policies;

use Litepie\User\Contracts\UserPolicy;
use Teste\Teste\Models\Modelo;

class ModeloPolicy
{

    /**
     * Determine if the given user can view the modelo.
     *
     * @param UserPolicy $user
     * @param Modelo $modelo
     *
     * @return bool
     */
    public function view(UserPolicy $user, Modelo $modelo)
    {
        if ($user->canDo('teste.modelo.view') && $user->isAdmin()) {
            return true;
        }

        return $modelo->user_id == user_id() && $modelo->user_type == user_type();
    }

    /**
     * Determine if the given user can create a modelo.
     *
     * @param UserPolicy $user
     * @param Modelo $modelo
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('teste.modelo.create');
    }

    /**
     * Determine if the given user can update the given modelo.
     *
     * @param UserPolicy $user
     * @param Modelo $modelo
     *
     * @return bool
     */
    public function update(UserPolicy $user, Modelo $modelo)
    {
        if ($user->canDo('teste.modelo.edit') && $user->isAdmin()) {
            return true;
        }

        return $modelo->user_id == user_id() && $modelo->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given modelo.
     *
     * @param UserPolicy $user
     * @param Modelo $modelo
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Modelo $modelo)
    {
        return $modelo->user_id == user_id() && $modelo->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given modelo.
     *
     * @param UserPolicy $user
     * @param Modelo $modelo
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Modelo $modelo)
    {
        if ($user->canDo('teste.modelo.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given modelo.
     *
     * @param UserPolicy $user
     * @param Modelo $modelo
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Modelo $modelo)
    {
        if ($user->canDo('teste.modelo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
